About Me
########


By day I confabulate wapdoodles and at night I subvorbify langfettled mees.


Skills
~~~~~~

- Wapdoodle confabulation
- Mees subvorbification


Favorite Things
~~~~~~~~~~~~~~~

- Belgian beer
- Peaty single-malt whiskey
- Cheesy chips and gravy


